import React__default, { useState, useContext, useCallback } from 'react';
import { ThemeProvider } from '@rescui/ui-contexts';
import Input from '@rescui/input';
import Switcher from '@rescui/switcher';
import { CloseIcon, ErrorIcon } from '@rescui/icons';
import styles from './full-search.module.pcss.js';
import { useSearch } from '../search-wrapper/use-search.js';
import { ResultsList } from './results-list/results-list.js';
import SearchContext from '../search-wrapper/search-context.js';

const FullSearch = ({
  searchString,
  killSearch
}) => {
  const [inputValue, setInputValue] = useState(searchString);
  const {
    hits,
    placeholder
  } = useSearch(inputValue, 75);
  const {
    matching,
    matchingOptions,
    setMatching
  } = useContext(SearchContext);
  const clearSearch = useCallback(() => {
    setInputValue('');
  }, []);
  const handleSwitcherChange = useCallback(value => {
    setMatching(value);
  }, []);
  const handleInputChange = useCallback(e => {
    setInputValue(e.target.value);
  }, [inputValue]);
  return React__default.createElement(ThemeProvider, {
    theme: 'light'
  }, React__default.createElement("div", {
    className: styles.fullSearch
  }, React__default.createElement("div", {
    className: styles.header
  }, React__default.createElement("button", {
    className: styles.closeSearch,
    onClick: killSearch
  }, React__default.createElement(CloseIcon, {
    size: 'l'
  })), React__default.createElement("div", {
    className: styles.wrapper
  }, React__default.createElement(Input, {
    placeholder: 'Search',
    value: inputValue,
    onClear: clearSearch,
    onChange: handleInputChange,
    clearIcon: React__default.createElement(ErrorIcon, null),
    size: 'l',
    autoFocus: true
  }), React__default.createElement("div", {
    className: styles.switcher
  }, React__default.createElement(Switcher, {
    value: matching,
    onChange: handleSwitcherChange,
    options: matchingOptions,
    size: 'xs'
  })))), React__default.createElement("div", {
    className: styles.wrapper
  }, inputValue && React__default.createElement(ResultsList, {
    placeholder: placeholder,
    hits: hits
  }))));
};

export { FullSearch };
